==> AstroScheduller-0.9.3.2205.tar.gz: AstroScheduller-0.9.3.2205/README.md <==
![astro_scheduller](https://raw.githubusercontent.com/AstroScheduller/AstroScheduller/Dev/docs/astro_scheduller.jpg)

# AstroScheduller 0.9.3

[![](https://img.shields.io/badge/license-MIT-green)](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/LICENSE)
[![](https://img.shields.io/badge/release-v0.9.3-informational)](https://github.com/AstroScheduller/AstroScheduller/releases)
[![](https://img.shields.io/badge/python-3.6+-orange)]()
[![CodeQL](https://github.com/AstroScheduller/AstroScheduller/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/AstroScheduller/AstroScheduller/actions/workflows/codeql-analysis.yml)

The AstroScheduller project is developing a user-friendly Python package with an algorithm for planning astronomical observations. This project was taken from a previous project [AstroScheduller.py](https://github.com/AstroScheduller/AstroSchedullerPy).

Using PiPI to install:

```shell
pip install AstroScheduller
```

For more information about the installation, see [Getting Started: Installation](https://astroscheduller.github.io/tutorials-docs/getting-started.html#installation)

Demo on Google Colab: 
 - [Introduction to AstroScheduller](https://colab.research.google.com/drive/1pnGP9p53ELxzyRdV7aMAa21Q0RGHIbaM?usp=sharing)

## Documentations

 - [AstroScheduller Documentation Homepage](https://astroscheduller.github.io/)
 - [Appendix: Technical Documentation for AstroSchedullerGo](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/docs/app_astroschedullergo_tech.md)

## To-do

See [todo.md](./docs/todo.md). 

## License

The AstroScheduller Project and AstroSchedullerGo are released as open source projects under the MIT license. See [LICENSE](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/LICENSE) for more information. 

## Acknowledgement

We are deeply grateful to the researchers and students at the Shanghai Astronomical Observatory of the Chinese Academy of Sciences for their thoughtful discussions and work on testing the algorithm.

==> AstroScheduller-1.0.1.2210.tar.gz: AstroScheduller-1.0.1.2210/README.md <==
![astro_scheduller](https://raw.githubusercontent.com/AstroScheduller/AstroScheduller/Dev/docs/astro_scheduller.jpg)

# AstroScheduller 0.9.3

[![](https://img.shields.io/badge/license-MIT-green)](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/LICENSE)
[![](https://img.shields.io/badge/release-v0.9.3-informational)](https://github.com/AstroScheduller/AstroScheduller/releases)
[![](https://img.shields.io/badge/python-3.6+-orange)]()
[![CodeQL](https://github.com/AstroScheduller/AstroScheduller/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/AstroScheduller/AstroScheduller/actions/workflows/codeql-analysis.yml)

The AstroScheduller project is developing a user-friendly Python package with an algorithm for planning astronomical observations. This project was taken from a previous project [AstroScheduller.py](https://github.com/AstroScheduller/AstroSchedullerPy).

Using PiPI to install:

```shell
pip install AstroScheduller
```

For more information about the installation, see [Getting Started: Installation](https://astroscheduller.github.io/tutorials-docs/getting-started.html#installation)

Demo on Google Colab: 
 - [Introduction to AstroScheduller](https://colab.research.google.com/drive/1pnGP9p53ELxzyRdV7aMAa21Q0RGHIbaM?usp=sharing)
 - [AstroScheduller Examples](https://colab.research.google.com/drive/1fHDBcop4ZaMf3P7huPEB-w_y5VkIsI2X?usp=sharing)

## Documentations

 - [AstroScheduller Documentation Homepage](https://astroscheduller.github.io/)
 - [Appendix: Technical Documentation for AstroSchedullerGo](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/docs/app_astroschedullergo_tech.md)

## To-do

See [todo.md](./docs/todo.md). 

## License

The AstroScheduller Project and AstroSchedullerGo are released as open source projects under the MIT license. See [LICENSE](https://github.com/AstroScheduller/AstroScheduller/blob/Dev/LICENSE) for more information. 

## Acknowledgement

We are deeply grateful to the researchers and students at the Shanghai Astronomical Observatory of the Chinese Academy of Sciences for their thoughtful discussions and work on testing the algorithm.
